==> haskell-data-serializer-0.3.4-65-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-data-serializer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-serializer
version: 0.3.4
id: data-serializer-0.3.4-LMd3ae2oY4DGyCiIjoPJPQ
key: data-serializer-0.3.4-LMd3ae2oY4DGyCiIjoPJPQ
license: BSD-3-Clause
copyright: 2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-serializer
synopsis: Common API for serialization libraries
description:
    This package provides a common API for serialization libraries like
    <http://hackage.haskell.org/package/binary binary> and
    <http://hackage.haskell.org/package/cereal cereal>.
category: Data
abi: da4c5bb27b91abe36510e84a9d8a338a
exposed: True
exposed-modules:
    Data.Deserializer Data.Serializer
import-dirs: /usr/lib/ghc-8.6.5/site-local/data-serializer-0.3.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/data-serializer-0.3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/data-serializer-0.3.4
hs-libraries: HSdata-serializer-0.3.4-LMd3ae2oY4DGyCiIjoPJPQ
depends:
    base-4.12.0.0 binary-0.8.6.0 bytestring-0.10.8.2
    cereal-0.5.8.1-7AyRb7vLva5K85rZXh3kQh
    data-endian-0.1.1-8eI15msEBjH5vqdbWN68zz
    parsers-0.12.10-KOAf7LSEBghE1cBkw6ZYub
    split-0.2.3.3-7ukSI7OZicINGuE3hgII
haddock-interfaces: /usr/share/doc/haskell-data-serializer/html/data-serializer.haddock
haddock-html: /usr/share/doc/haskell-data-serializer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-serializer-0.3.4-66-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-data-serializer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-serializer
version: 0.3.4
id: data-serializer-0.3.4-LirV1w5cT1NJvDpqbbtB18
key: data-serializer-0.3.4-LirV1w5cT1NJvDpqbbtB18
license: BSD-3-Clause
copyright: 2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-serializer
synopsis: Common API for serialization libraries
description:
    This package provides a common API for serialization libraries like
    <http://hackage.haskell.org/package/binary binary> and
    <http://hackage.haskell.org/package/cereal cereal>.
category: Data
abi: 2f1316cd504e4eb9968e7d2c9fa0b4a7
exposed: True
exposed-modules:
    Data.Deserializer Data.Serializer
import-dirs: /usr/lib/ghc-8.6.5/site-local/data-serializer-0.3.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/data-serializer-0.3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/data-serializer-0.3.4
hs-libraries: HSdata-serializer-0.3.4-LirV1w5cT1NJvDpqbbtB18
depends:
    base-4.12.0.0 binary-0.8.6.0 bytestring-0.10.8.2
    cereal-0.5.8.1-7AyRb7vLva5K85rZXh3kQh
    data-endian-0.1.1-8eI15msEBjH5vqdbWN68zz
    parsers-0.12.10-541kXjcFT8WAZuoEnVv4Fv
    split-0.2.3.3-4dhvbosBVIlDAhhwnzSbSM
haddock-interfaces: /usr/share/doc/haskell-data-serializer/html/data-serializer.haddock
haddock-html: /usr/share/doc/haskell-data-serializer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
